<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation>Un client Jabber/XMPP, simple et convivial</translation>
    </message>
    <message>
        <source>License:</source>
        <translation>Licence :</translation>
    </message>
    <message>
        <source>Source code on GitHub</source>
        <translation type="vanished">Code source sur GitHub</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation>Voir le code source en ligne</translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation>Signaler un problème</translation>
    </message>
</context>
<context>
    <name>AboutPage</name>
    <message>
        <source>About</source>
        <translation type="vanished">À propos</translation>
    </message>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation type="vanished">Un client Jabber/XMPP, simple et convivial</translation>
    </message>
    <message>
        <source>Sourcecode on GitHub</source>
        <translation type="vanished">Code source sur GitHub</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Fermer</translation>
    </message>
</context>
<context>
    <name>AboutSheet</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation type="vanished">Un client Jabber/XMPP, simple et convivial</translation>
    </message>
    <message>
        <source>License:</source>
        <translation type="vanished">Licence :</translation>
    </message>
    <message>
        <source>Source code on GitHub</source>
        <translation type="vanished">Code source sur GitHub</translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientAndServerConfirmationPage</name>
    <message>
        <source>Delete account completely</source>
        <translation type="vanished">Supprimer le compte définitivement</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation type="vanished">Votre compte va être définitivement supprimé. C&apos;est à dire sur l&apos;application locale et sur le serveur.
Vous ne serez plus en capacité d&apos;utiliser ce compte à nouveau !</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Supprimer</translation>
    </message>
</context>
<context>
    <name>AccountDeletionFromClientConfirmationPage</name>
    <message>
        <source>Remove account from this app</source>
        <translation type="vanished">Supprimer ce compte de l&apos;application</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
You won&apos;t be able to get your credentials back!
Make sure that you have backed up those if you want to use your account later.</source>
        <translation type="vanished">Votre compte va être supprimé de l&apos;application.
Vous n&apos;aurez plus accès à vos identifiants !
Assurez vous d&apos;en avoir fais une copie si vous comptez réutiliser ce compte plus tard.</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Supprimer</translation>
    </message>
</context>
<context>
    <name>AccountDeletionPage</name>
    <message>
        <source>Delete account</source>
        <translation type="vanished">Supprimer le compte</translation>
    </message>
    <message>
        <source>You can remove your account &lt;b&gt;%1&lt;/b&gt; only from this app or delete it completely. If you delete your account completely, you won&apos;t be able to use it with another app because it is also removed from the server.</source>
        <translation type="vanished">Vous pouver supprimer votre compte &lt;b&gt;%1&lt;/b&gt; seulement de l&apos;application ou complètement. Si vous supprimez complètement votre compte, vous ne pourrez plus l&apos;utiliser avec une autre application parce qu&apos;il sera aussi supprimé du server.</translation>
    </message>
    <message>
        <source>Remove from this app</source>
        <translation type="vanished">Supprimer de l&apos;application</translation>
    </message>
    <message>
        <source>Delete completely</source>
        <translation type="vanished">Supprimer définitivement</translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation>Sécurité du compte</translation>
    </message>
    <message>
        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
        <translation>Autoriser l&apos;ajout de nouveaux appareils en utilisant un code QR, mais ne jamais afficher le mot de passe sous forme de texte. Cette action ne peut pas être annulée, veuillez donc envisager de stocker le mot de passe d&apos;une autre manière avant de l&apos;utiliser.</translation>
    </message>
    <message>
        <source>Disable showing the password</source>
        <translation>Désactiver l&apos;affichage du mot de passe</translation>
    </message>
    <message>
        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
        <translation>N&apos;expose pas le mot de passe sous quelque forme que ce soit. Cette action ne peut pas être annulée.</translation>
    </message>
    <message>
        <source>Disable showing the QR-Code and password</source>
        <translation>Désactiver l&apos;affichage du code QR et d mot de passe</translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation>Transférer le compte vers un autre appareil</translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation>Scannez le QR code ou entrez les identifiants sur un autre appareil pour vous y connecter.

Attention :
Ne montrez ce QR code à personne d&apos;autre. Il permet un accès complet à votre compte !</translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation>Adresse de clavardage :</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe :</translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation>Cacher le QR code</translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation>Afficher comme QR code</translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation>Cacher le texte</translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation>Afficher comme texte</translation>
    </message>
</context>
<context>
    <name>BackButton</name>
    <message>
        <source>Navigate Back</source>
        <translation type="vanished">Retour</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation>Modifier le mot de passe</translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation>Mot de passe actuel :</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Nouveau mot de passe :</translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation>Nouveau mot de passe (répétez) :</translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation>Les nouveaux mots de passe ne sont pas identiques.</translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation>Le mot de passe actuel est invalide.</translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation>Vous devez être connecté(e) pour modifier votre mot de passe.</translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation>Après modification de votre mot de passe, vous devrez le ressaisir sur tous vos autres appareils.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Changer</translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Message copied to clipboard</source>
        <translation type="vanished">Message copié dans le presse-papier</translation>
    </message>
    <message>
        <source>Copy Message</source>
        <translation type="vanished">Copier le message</translation>
    </message>
    <message>
        <source>Edit Message</source>
        <translation type="vanished">Modifier le message</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>Révélation</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Télécharger</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="vanished">Copier le lien de téléchargement</translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation>Copier le message</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation>Modifier le message</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation>Copier le lien de téléchargement</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation>Citer le message</translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation>Écrire un message</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="vanished">Envoyer</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Image</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Vidéo</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Audio</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="vanished">Document</translation>
    </message>
    <message>
        <source>Other file</source>
        <translation type="vanished">Autre fichier</translation>
    </message>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Sélectionner un fichier</translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation>Envoyer un message contenant une révélation</translation>
    </message>
    <message>
        <source>Spoiler hint</source>
        <translation>Indice sur la révélation</translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation>Réactiver les notifications</translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation>Désactiver les notifications</translation>
    </message>
    <message>
        <source>View profile</source>
        <translation>Afficher le profil</translation>
    </message>
    <message>
        <source>Multimedia settings</source>
        <translation type="vanished">Paramètres multimédia</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Rechercher vers le haut</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Rechercher vers le bas</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <source>Copy message</source>
        <translation type="vanished">Copier le message</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation type="vanished">Modifier le message</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="vanished">Copier le lien de téléchargement</translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation type="vanished">Citer le message</translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation>Votre compte ne peut pas être supprimé du serveur. Il m&apos;a pas été non plus supprimé de l&apos;application : %1</translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation>Très bas</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Bas</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Haut</translation>
    </message>
    <message>
        <source>Very high</source>
        <translation>Très haut</translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation>Qualité constante</translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation>Débit binaire constant</translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation>Débit binaire moyen</translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation>Deux passes</translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>ContextDrawer</name>
    <message>
        <source>Actions</source>
        <translation type="vanished">Actions</translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Remove password completely</source>
        <translation>Supprimer complètement le mot de passe</translation>
    </message>
    <message>
        <source>Your password will not be included in the QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation>Votre mot de passe ne sera plus inclus dans le code QR.
Vous ne pourrez plus utiliser la connexion par code QR sans saisir de nouveau votre mot de passe car cette action ne peut pas être annulée !
Assurez-vous que vous l&apos;avez sauvegardé si vous voulez utiliser votre compte plus tard.</translation>
    </message>
    <message>
        <source>Remove password</source>
        <translation>Supprimer le mot de passe</translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Do not show password as text</source>
        <translation>Ne pas afficher le mot de passe sous forme de texte</translation>
    </message>
    <message>
        <source>Your password will not be shown as text anymore.
You won&apos;t be able to see your password as text again because this action cannot be undone!
Make sure that you backed it up if you want to use your account later.</source>
        <translation>Votre mot de passe ne sera plus affiché sous forme de texte.
Vous ne pourrez plus voir votre mot de passe sous forme de texte car cette action ne peut pas être annulée !
Assurez-vous que vous l&apos;avez sauvegardé si vous voulez utiliser votre compte plus tard.</translation>
    </message>
    <message>
        <source>Do not show password</source>
        <translation>Ne pas afficher le mot de passe</translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation>Impossible d&apos;enregistrer le fichier : %1</translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation>Échec du téléchargement : %1</translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>People</source>
        <translation>Personnes</translation>
    </message>
    <message>
        <source>Nature</source>
        <translation>Nature</translation>
    </message>
    <message>
        <source>Food</source>
        <translation>Nourriture</translation>
    </message>
    <message>
        <source>Activity</source>
        <translation>Activités</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation>Voyage</translation>
    </message>
    <message>
        <source>Objects</source>
        <translation>Objets</translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation>Symboles</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Drapeaux</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation>Rechercher un émoji</translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation>Sélectionnez une discussion pour commencer à échanger</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <source>Select a file</source>
        <translation type="vanished">Sélectionnez un fichier</translation>
    </message>
</context>
<context>
    <name>FileChooserMobile</name>
    <message>
        <source>go to parent folder</source>
        <translation type="vanished">aller au dossier parent</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Fermer</translation>
    </message>
    <message>
        <source>Go to parent folder</source>
        <translation type="vanished">Aller au dossier parent</translation>
    </message>
</context>
<context>
    <name>ForwardButton</name>
    <message>
        <source>Navigate Forward</source>
        <translation type="vanished">Naviguer en avant</translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>Log out</source>
        <translation type="vanished">Se déconnecter</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation type="vanished">Ajouter un nouveau contact</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="vanished">Retour</translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation>Inviter des amis</translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation>Lien d&apos;invitation copié dans le presse-papier</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Hors ligne</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>En ligne</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Connexion en cours…</translation>
    </message>
    <message>
        <source>Transfer account</source>
        <translation type="vanished">Transférer le compte</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="vanished">Supprimer le compte</translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation>Permuter d&apos;appareil</translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">Impossible d&apos;envoyer le message car vous n&apos;êtes pas connecté(e).</translation>
    </message>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation type="vanished">Impossible d&apos;ajouter un contact car vous n&apos;êtes pas connecté(e).</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation type="vanished">Impossible de supprimer le contact car vous n&apos;êtes pas connecté(e).</translation>
    </message>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation>Le lien s&apos;ouvrira une fois que vous serez connecté(e).</translation>
    </message>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation type="vanished">Impossible d&apos;envoyer le fichier car vous n&apos;êtes pas connecté(e).</translation>
    </message>
    <message>
        <source>No password found. Please enter it.</source>
        <translation type="vanished">Aucun mot de passe trouvé. Veuillez le saisir.</translation>
    </message>
    <message>
        <source>No valid login QR code found.</source>
        <translation>Aucun code QR de connexion valide trouvé.</translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation>Supprimer ce compte de l&apos;application</translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation>Votre compte sera supprimé de l&apos;application.
Votre mot de passe sera supprimé, assurez-vous qu&apos;il est enregistré dans un gestionnaire de mots de passe ou que vous le connaissez !</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Your Jabber-ID:</source>
        <translation type="vanished">Votre identifiant Jabber :</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation type="vanished">identifiant@exemple.org</translation>
    </message>
    <message>
        <source>Your Password:</source>
        <translation type="vanished">Votre mot de passe :</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="vanished">Réessayer</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Rejoindre</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Connexion en cours…</translation>
    </message>
    <message>
        <source>Log in</source>
        <translation>Se connecter</translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation>Connexion à votre compte Jabber</translation>
    </message>
    <message>
        <source>Your diaspora*-ID:</source>
        <translation type="vanished">Votre identifiant diaspora* :</translation>
    </message>
    <message>
        <source>user@diaspora.pod</source>
        <translation type="vanished">utilisateur@diaspora.pod</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="vanished">Identifiant ou mot de passe invalide.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="vanished">Impossible de se connecter au serveur. Veuillez tester votre connexion à internet.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="vanished">Le serveur ne permet pas les connexions sécurisées.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="vanished">Une erreur est survenue lors de la connexion sécurisée.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your JID again.</source>
        <translation type="vanished">Impossible d&apos;atteindre l&apos;adresse du serveur. Veuillez vérifier votre identifiant Jabber.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="vanished">Impossible de se connecter au serveur.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="vanished">Protocole d&apos;authentification non supporté par le serveur.</translation>
    </message>
    <message>
        <source>An unknown error occured; see log for details.</source>
        <translation type="vanished">Une erreur inconnue est survenue, consultez les journaux pour plus de détails.</translation>
    </message>
    <message>
        <source>Log in using a QR-Code</source>
        <translation type="vanished">Connexion à l&apos;aide d&apos;un code QR</translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation>Prendre une photo</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Enregistrer une vidéo</translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation>Enregistrer ma voix</translation>
    </message>
    <message>
        <source>Send location</source>
        <translation>Envoyer ma position</translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation>Choisir un fichier</translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation>Choisir une image</translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation>Choisir une vidéo</translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation>Choisir un fichier audio</translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation>Choisir un document</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation>Fichiers audio</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Could not send message, as a result of not being connected.</source>
        <translation type="vanished">Impossible d&apos;envoyer le message car vous n&apos;êtes pas connecté(e).</translation>
    </message>
    <message>
        <source>Could not correct message, as a result of not being connected.</source>
        <translation type="vanished">Impossible de corriger le message car vous n&apos;êtes pas connecté(e).</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation type="vanished">Révélation</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Le message n&apos;a pas pu être envoyé.</translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation>La correction du message a échoué.</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation>En attente</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Envoyé</translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation>Délivré</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation>Paramètres multimédia</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configurer</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation>Capturer une image</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation>Enregistrement audio</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation>Enregistrement vidéo</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Caméra</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation>Entrée audio</translation>
    </message>
    <message>
        <source>Container</source>
        <translation>Conteneur</translation>
    </message>
    <message>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vidéo</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Résolution</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualité</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Taux d&apos;échantillonnage</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation>Images par seconde</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Prêt</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Initialisation…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Indisponible</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation>Enregistrement…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>En pause</translation>
    </message>
</context>
<context>
    <name>MultimediaSettingsPage</name>
    <message>
        <source>Multimedia Settings</source>
        <translation type="vanished">Paramètres multimédia</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="vanished">Configurer</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation type="vanished">Capturer une image</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation type="vanished">Enregistrement audio</translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation type="vanished">Enregistrement vidéo</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="vanished">Caméra</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation type="vanished">Entrée audio</translation>
    </message>
    <message>
        <source>Container</source>
        <translation type="vanished">Conteneur</translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="vanished">Image</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="vanished">Audio</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Vidéo</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="vanished">Codec</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="vanished">Résolution</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="vanished">Qualité</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation type="vanished">Taux d&apos;échantillonnage</translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation type="vanished">Images par seconde</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="vanished">Prêt</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation type="vanished">Initialisation…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation type="vanished">Indisponible</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation type="vanished">Enregistrement…</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="vanished">En pause</translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Ready</source>
        <translation>Prêt</translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation>Initialisation…</translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>Indisponible</translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation>Enregistrement… %1</translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation>En pause %1</translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation>Supprimer le mot de passe</translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation>Vous pouvez décider non seulement de ne pas afficher votre mot de passe pour &lt;b&gt;%1&lt;/b&gt; sous forme de texte ou de le supprimer complètement lors du transfert de compte. Si vous supprimez complètement votre mot de passe, vous ne pourrez plus utiliser le transfert de compte par lecture optique sans saisir votre mot de passe, car il est également supprimé du code QR.</translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation>Ne pas afficher le mot de passe sous forme de texte</translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation>Supprimer complètement</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation>Noter comme lu</translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation>Libre pour discuter</translation>
    </message>
    <message>
        <source>Away</source>
        <translation>Absent(e)</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation>Ne pas déranger</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation>Absent(e) pour longtemps</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Hors ligne</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="vanished">Invisible</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation>Identifiant ou mot de passe invalide.</translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation>Impossible de se connecter au serveur. Veuillez tester votre connexion à internet.</translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation>Le serveur ne permet pas les connexions sécurisées.</translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation>Une erreur est survenue lors de la connexion sécurisée.</translation>
    </message>
    <message>
        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
        <translation>Impossible de trouver l&apos;adresse du serveur. Merci de vérifier le nom du serveur.</translation>
    </message>
    <message>
        <source>Could not connect to the server.</source>
        <translation type="obsolete">Impossible de se connecter au serveur.</translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation>Protocole d&apos;authentification non pris en charge par le serveur.</translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation>Ce serveur ne gère pas l&apos;inscription.</translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation>Le server est hors ligne ou bloqué par un pare-feu.</translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation>La connection ne peut pas être actualisée.</translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation>L&apos;accès à internet n&apos;est pas autorisé. Merci de vérifier les permissions système.</translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation>Échec de la génération du QR code : %1</translation>
    </message>
</context>
<context>
    <name>QrCodeScannerPage</name>
    <message>
        <source>Scan QR code</source>
        <translation>Scanner le code QR</translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation>Aucune caméra n&apos;est disponible.</translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation>Vitre caméra est occupée.
Essayez de fermer d&apos;autres applications utilisant la caméra.</translation>
    </message>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation>Le format « %1 » de la caméra n&apos;est pas pris en charge.</translation>
    </message>
    <message>
        <source>Logging in…</source>
        <translation type="vanished">Connexion…</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation>Scanner le QR code de votre appareil pour transférer votre compte.</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation>Afficher des explications</translation>
    </message>
    <message>
        <source>Scan</source>
        <translation>Scanner</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation>Continuer sans QR Code</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Connexion…</translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation>Configurer</translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation>Créer un nouveau compte</translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation>Utiliser un compte existant</translation>
    </message>
</context>
<context>
    <name>RegistrationManager</name>
    <message>
        <source>Password changed successfully.</source>
        <translation>Le mot de passe a été changé avec succès.</translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation>Échec lors de la modification du mot de passe : %1</translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation>Supprimer complètement le compte</translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation>Votre compte va être complètement supprimé. C&apos;est-à-dire localement dans l&apos;application et sur le serveur.
Vous ne pourrez plus utiliser ce compte à nouveau !</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Nickname:</source>
        <translation>Pseudonyme :</translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation>Identifiant Jabber :</translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation>identifiant@exemple.org</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Ajouter un nouveau contact</translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation>Cette action va aussi envoyer une requête pour s&apos;assurer de la présence du contact.</translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation>Message facultatif :</translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation>Informez votre contact sur votre identité.</translation>
    </message>
</context>
<context>
    <name>RosterListItem</name>
    <message>
        <source>Error: Please check the JID.</source>
        <translation>Erreur : veuillez vérifier votre identifiant Jabber.</translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="vanished">Disponible</translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="vanished">Libre pour discuter</translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="vanished">Absent(e)</translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">Ne pas déranger</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="vanished">Absent(e) pour longtemps</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="vanished">Hors ligne</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Erreur</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation type="vanished">Invalide</translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation>Impossible d&apos;ajouter un contact car vous n&apos;êtes pas connecté(e).</translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation>Impossible de supprimer le contact car vous n&apos;êtes pas connecté(e).</translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation type="vanished">Cette action va aussi envoyer une requête pour s&apos;assurer de la présence du contact.</translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation type="vanished">Message facultatif :</translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation type="vanished">Informez votre contact de votre identité.</translation>
    </message>
    <message>
        <source>Spoiler</source>
        <translation>Révélation</translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation>Impossible de renommer le contact, car vous n&apos;êtes pas connecté(e).</translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Contacts</source>
        <translation>Contacts</translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation>Ajouter un nouveau contact</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>Connexion en cours…</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Hors ligne</translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation>Rechercher des contacts</translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Do you really want to delete the contact &quot;%1&quot; from your roster?</source>
        <translation type="vanished">Voulez-vous vraiment supprimer le contact « %1 » de votre répertoire ?</translation>
    </message>
    <message>
        <source>Delete contact</source>
        <translation>Supprimer le contact</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
        <translation>Voulez-vous vraiment supprimer le contact &lt;b&gt;%1&lt;/b&gt; de votre répertoire ?</translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation>Renommer le contact</translation>
    </message>
    <message>
        <source>Edit name:</source>
        <translation type="vanished">Modifier le nom :</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Envoyer</translation>
    </message>
    <message>
        <source>Subscription Request</source>
        <translation type="vanished">Demande d&apos;abonnement</translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation type="vanished">Vous avez reçu une demande d&apos;abonnement de la part de &lt;b&gt;%1&lt;/b&gt;. Si vous acceptez, il aura accès à votre statut de présence.</translation>
    </message>
    <message>
        <source>Decline</source>
        <translation type="vanished">Refuser</translation>
    </message>
    <message>
        <source>Caption</source>
        <translation>Légende</translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation>Autre serveur</translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation>Pas de limites</translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation>%1 jours</translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Change password</source>
        <translation>Modifier le mot de passe</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation>Modifie le mot de passe du compte. Vous devrez le ressaisir sur tous vos autres appareils.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation>Paramètres multimédia</translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation>Configurer les paramètres d&apos;enregistrement des photos, video et audio</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Account security</source>
        <translation>Sécurité du compte</translation>
    </message>
    <message>
        <source>configure whether this device can be used to log in on a new device</source>
        <translation>Configurer si cet appareil peut être utilisé pour se connecter à un nouvel appareil</translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation>Supprimer ce compte de Kaidan</translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation>Supprimer ce compte de l&apos;application</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation>Supprimer ce compte</translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation>Supprimer ce compte du serveur</translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation type="vanished">Modifier le mot de passe</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="vanished">Modifie le mot de passe du compte. Vous devrez le ressaisir sur tous vos autres appareils.</translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation type="obsolete">Paramètres multimédia</translation>
    </message>
</context>
<context>
    <name>SettingsSheet</name>
    <message>
        <source>Settings</source>
        <translation type="vanished">Paramètres</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation>Profitez d&apos;une communication libre sur tous vos appareils !</translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation>C&apos;est parti</translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation>Demande d&apos;abonnement</translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation>Vous avez reçu une demande d&apos;abonnement de la part de &lt;b&gt;%1&lt;/b&gt;. Si vous acceptez, il aura accès à votre statut de présence.</translation>
    </message>
    <message>
        <source>Decline</source>
        <translation>Refuser</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Accepter</translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation>Impossible d&apos;envoyer le fichier car vous n&apos;êtes pas connecté(e).</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation type="vanished">Accepter</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <source>More Actions</source>
        <translation type="vanished">Plus d&apos;actions</translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation>Le message n&apos;a pas pu être envoyé.</translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation>Profil</translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Pseudo</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Courriel</translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation>Anniversaire</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Site web</translation>
    </message>
</context>
</TS>
